@@ -1500,11 +1500,14 @@ class TopicApiBaseMixin(object):
             - `template_params` dict containing the query template parameters
             - `select_suggesters` (optional) list containing suggesters to be used.
                 If no suggesters are selected, all suggesters are executed by default.
-                Available suggesters: ["facet_value", "facet_name", "content_phrase", "saved_search"]
+                Available suggesters:
                 - "facet_value": Complete on facet-values that have "autocomplete" enabled (Exact Search)
                 - "facet_name: Help to find the correct facet
                 - "content_phrase": Complete on key-phrases + item-title (Fuzzy Search) added via NLP-Tagger
                 - "saved_search": Complete on queries saved by the user
+                - "popular_query": Complete on popular queries on the project, filtered by user_id (optional)
+                - "search_history": Triggered only to pre-populate and show default-suggestions.
+                                    Returns last-N searches, filtered by project_id and user_id.
         :param filter_query: Squirro query to limit the typeahead suggestions.
             Must be of type `string`. Defaults to `None` if not specified. As
             an example, this parameter can be used to filter the typeahead
