@@ -15,10 +15,12 @@ class MLTemplatesMixin(object):
     #
     #  ML Templates
     #
-    def get_templates(self, project_id):
+    def get_templates(self, project_id, groundtruth_id=None):
         """Return all available Templates.
 
         :param project_id: Id of the Squirro project.
+        :param groundtruth_id: Id of the Ground Truth (for enriching template with
+                               default values).
         """
         url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/ml_template" % {
             "ep": self.topic_api_url,
@@ -27,7 +29,9 @@ class MLTemplatesMixin(object):
         }
 
         headers = {"Content-Type": "application/json"}
-        res = self._perform_request("get", url, headers=headers)
+
+        data = {"groundtruth_id": groundtruth_id}
+        res = self._perform_request("get", url, headers=headers, params=data)
         return self._process_response(res)
 
     def get_template(self, project_id, template_id, groundtruth_id=None):
@@ -36,7 +40,7 @@ class MLTemplatesMixin(object):
         :param project_id: Id of the Squirro project.
         :param template_id: Id of the machine learning Template.
         :param groundtruth_id: Id of the Ground Truth (for enriching template with
-        default values).
+                               default values).
         :return:
         """
         url = (
@@ -63,7 +67,6 @@ class MLTemplatesMixin(object):
         :param project_id: Id of the Squirro project.
         :param template_id: id of the template.
         :param params: dictionary that contains the parameters for the template.
-
         """
 
         url = (
